Don't use the abbreviation "win" to refer to Windows (Bug#10421).
authorPaul Eggert <eggert@cs.ucla.edu>
Sun, 29 Jul 2012 08:18:29 +0000 (01:18 -0700)
committerPaul Eggert <eggert@cs.ucla.edu>
Sun, 29 Jul 2012 08:18:29 +0000 (01:18 -0700)
* lisp/org/ob-lilypond.el (ly-w32-ly-path): Rename from ly-win32-ly-path.
(ly-w32-pdf-path): Rename from ly-win32-pdf-path.
(ly-w32-midi-path): Rename from ly-win32-midi-path.
(ly-determine-ly-path, ly-determine-pdf-path, ly-determine-midi-path):
Check for "windows-nt", not "win32", in system-type.
* src/regex.c (MAX_BUF_SIZE): Remove some incorrect and
long-ago-commented-out code that talks about "WIN32".
* src/w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95.
All uses changed.

48 files changed:
doc/misc/ChangeLog
doc/misc/gnus-faq.texi
doc/misc/gnus.texi
doc/misc/idlwave.texi
doc/misc/mh-e.texi
leim/makefile.w32-in
lib-src/makefile.w32-in
lib/makefile.w32-in
lisp/ChangeLog
lisp/ChangeLog.8
lisp/dos-w32.el
lisp/mail/feedmail.el
lisp/makefile.w32-in
lisp/mh-e/ChangeLog.1
lisp/net/ange-ftp.el
lisp/org/ChangeLog
lisp/org/ob-lilypond.el
lisp/printing.el
nt/ChangeLog
nt/INSTALL
nt/configure.bat
nt/makefile.w32-in
src/ChangeLog
src/ChangeLog.10
src/ChangeLog.11
src/ChangeLog.6
src/ChangeLog.7
src/ChangeLog.8
src/dbusbind.c
src/makefile.w32-in
src/regex.c
src/sound.c
src/w32.c
src/w32console.c
src/w32fns.c
src/w32font.c
src/w32font.h
src/w32gui.h
src/w32heap.c
src/w32heap.h
src/w32inevt.c
src/w32inevt.h
src/w32menu.c
src/w32proc.c
src/w32select.c
src/w32term.c
src/w32term.h
src/w32xfns.c

index d2312db..fe76874 100644 (file)
 2007-11-07  Michael Albinus  <michael.albinus@gmx.de>
 
        * tramp.texi (Overview): Mention also the PuTTY integration under
-       Win32.  Remove paragraphs about Tramp's experimental status.
+       w32.  Remove paragraphs about Tramp's experimental status.
        (Frequently Asked Questions): Add code example for highlighting the
        mode line.
 
index 0c8c850..6c29465 100644 (file)
@@ -407,7 +407,7 @@ you want, so let's do it the correct way.
 The first thing you've got to do is to
 create a suitable directory (no blanks in directory name
 please) e.g. c:\myhome. Then you must set the environment
-variable HOME to this directory.  To do this under Win9x
+variable HOME to this directory.  To do this under Windows 9x
 or Me include the line
 
 @example
index df44937..afc324e 100644 (file)
@@ -29959,7 +29959,7 @@ Here's a typical score file:
 
 @lisp
 (("summary"
-  ("win95" -10000 nil s)
+  ("Windows 95" -10000 nil s)
   ("Gnus"))
  ("from"
   ("Lars" -1000))
index 030653b..feef325 100644 (file)
@@ -4020,7 +4020,7 @@ user is King!
 @end example
 
 @html
-<A NAME="WIN_MAC"></A>
+<A NAME="WINDOWS_MAC"></A>
 @end html
 @node Windows and MacOS, Troubleshooting, Configuration Examples, Top
 @appendix Windows and MacOS
index 538c3f1..f6adc43 100644 (file)
@@ -7901,7 +7901,7 @@ PATH=$PATH:/usr/bin/mh
 MAILDIR=$HOME/`mhparam Path`
 
 #
-# Filter messages with win32 executables/virii.
+# Filter messages with w32 executables/virii.
 #
 # These attachments are base64 and have a TVqQAAMAAAAEAAAA//8AALg
 # pattern. The string "this program cannot be run in MS-DOS mode"
@@ -9060,5 +9060,3 @@ Bill Wohler, August 2008
 @c Local Variables:
 @c sentence-end-double-space: nil
 @c End:
-
-
index e9a56e7..fa4afe8 100644 (file)
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for leim subdirectory in GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for leim subdirectory in GNU Emacs on the Microsoft Windows API.
 
 # Copyright (C) 2000-2012  Free Software Foundation, Inc.
 # Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
index 4b2b523..ba76c6d 100644 (file)
@@ -1,4 +1,4 @@
-#  -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+#  -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2012 Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.
index b49195b..3455207 100644 (file)
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2011 Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.
index fc96da8..d55ecc7 100644 (file)
        (tramp-completion-file-name-regexp-unified)
        (tramp-completion-file-name-regexp-separate)
        (tramp-completion-file-name-regexp-url): Don't use leading volume
-       letter on win32 systems.  (Bug#5303, Bug#9311)
+       letter on w32 systems.  (Bug#5303, Bug#9311)
        (tramp-drop-volume-letter): Simplify definition.
        Suggested by Stefan Monnier <monnier@iro.umontreal.ca>.
 
index ccc9b47..0380fb1 100644 (file)
        standard `print' and `nprint' programs, as well as `lpr' and
        similar programs.  Only write directly to the printer port if no
        print program is specified.  Work around a bug in Windows 9x
-       affecting Win32 version of Emacs by invoking command.com to write
+       affecting the w32 version of Emacs by invoking command.com to write
        to the printer port instead of writing directly.
        (direct-print-region-function): Use direct-print-region-helper to
        do most of the work.
index f68af7a..4839d6b 100644 (file)
@@ -361,7 +361,7 @@ filesystem mounted on drive Z:, FILESYSTEM could be \"Z:\"."
          (apply 'call-process lpr-prog nil errbuf nil rest))
         ;; Run command.com to access printer port on Windows 9x, unless
         ;; we are supposed to append to an existing (non-empty) file,
-        ;; to work around a bug in Windows 9x that prevents Win32
+        ;; to work around a bug in Windows 9x that prevents Windows
         ;; programs from accessing LPT ports reliably.
         ((and (eq system-type 'windows-nt)
               (getenv "winbootdir")
index c6d1d22..5202719 100644 (file)
@@ -2334,7 +2334,7 @@ mapped to mostly alphanumerics for safety."
     (if (and is-fqm is-in-this-dir)
        (setq filename buffer-file-name)
       (setq filename (feedmail-create-queue-filename queue-directory)))
-    ;; make binary file on DOS/Win95/WinNT, etc
+    ;; make binary file on DOS/Windows 95/Windows NT, etc
     (let ((buffer-file-type feedmail-force-binary-write))
       (write-file filename))
     ;; convenient for moving from draft to q, for example
index c7d883e..756d2b9 100644 (file)
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2012 Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.
index 94ac7a2..15b7380 100644 (file)
        * mh-utils.el (mh-find-progs): Run PATH search only when mh-progs,
        mh-lib and mh-lib-progs are not all already set.  This allows the
        user to set them using a simple setq prior to loading mh-e.  This
-       is useful for implementation of mh-e on win32.  Note that many
+       is useful for implementation of mh-e on w32.  Note that many
        commands still call mh-find-path which also parses the mh_profile
-       file (that may still fail on win32), so this is still done often.
+       file (that may still fail on w32), so this is still done often.
        But it lets us change the mh_profile file and have mh-e see the
        changed file without exiting emacs and starting over so I left
        that in.
index dd695c2..1501fa4 100644 (file)
@@ -2618,7 +2618,7 @@ away in the internal cache."
                                          (format
                                           "list data file %s not readable"
                                           temp))))
-                      ;; remove ^M inserted by the win32 ftp client
+                      ;; remove ^M inserted by the w32 ftp client
                       (while (re-search-forward "\r$" nil t)
                         (replace-match ""))
                       (goto-char 1)
index eae83f0..cf9c320 100644 (file)
@@ -1,3 +1,12 @@
+2012-07-29  Paul Eggert  <eggert@cs.ucla.edu>
+
+       Don't use the abbreviation "win" to refer to Windows (Bug#10421).
+       * ob-lilypond.el (ly-w32-ly-path): Rename from ly-win32-ly-path.
+       (ly-w32-pdf-path): Rename from ly-win32-pdf-path.
+       (ly-w32-midi-path): Rename from ly-win32-midi-path.
+       (ly-determine-ly-path, ly-determine-pdf-path, ly-determine-midi-path):
+       Check for "windows-nt", not "win32", in system-type.
+
 2012-06-02  Chong Yidong  <cyd@gnu.org>
 
        * org-clock.el (org-clock-string-limit)
index a1e4c9f..b3e77f3 100644 (file)
@@ -66,9 +66,9 @@ the midi file is not automatically played. Default value is t")
 (defvar ly-nix-pdf-path "evince")
 (defvar ly-nix-midi-path "timidity")
 
-(defvar ly-win32-ly-path "lilypond")
-(defvar ly-win32-pdf-path "")
-(defvar ly-win32-midi-path "")
+(defvar ly-w32-ly-path "lilypond")
+(defvar ly-w32-pdf-path "")
+(defvar ly-w32-midi-path "")
 
 (defvar ly-gen-png nil
 "Image generation (png) can be turned on by default by setting
@@ -329,8 +329,8 @@ If TEST is non-nil, it contains a simulation of the OS for test purposes"
          (or test system-type)))
     (cond ((string= sys-type  "darwin")
            ly-OSX-ly-path)
-          ((string= sys-type "win32")
-           ly-win32-ly-path)
+          ((string= sys-type "windows-nt")
+           ly-w32-ly-path)
           (t ly-nix-ly-path))))
 
 (defun ly-determine-pdf-path (&optional test)
@@ -341,8 +341,8 @@ If TEST is non-nil, it contains a simulation of the OS for test purposes"
          (or test system-type)))
     (cond ((string= sys-type  "darwin")
            ly-OSX-pdf-path)
-          ((string= sys-type "win32")
-           ly-win32-pdf-path)
+          ((string= sys-type "windows-nt")
+           ly-w32-pdf-path)
           (t ly-nix-pdf-path))))
 
 (defun ly-determine-midi-path (&optional test)
@@ -353,8 +353,8 @@ If TEST is non-nil, it contains a simulation of the OS for test purposes"
          (or test test system-type)))
     (cond ((string= sys-type  "darwin")
            ly-OSX-midi-path)
-          ((string= sys-type "win32")
-           ly-win32-midi-path)
+          ((string= sys-type "windows-nt")
+           ly-w32-midi-path)
           (t ly-nix-midi-path))))
 
 (defun ly-toggle-midi-play ()
index bf5b8a9..0152ed6 100644 (file)
@@ -2141,7 +2141,7 @@ Useful links:
   `http://bama.ua.edu/cgi-bin/man-cgi?lp'
   `http://www.mediacollege.com/cgi-bin/man/page.cgi?section=all&topic=lp'
 
-* GNU utilities for Win32 (cp.exe)
+* GNU utilities for w32 (cp.exe)
   `http://unxutils.sourceforge.net/'
 "
   :type '(repeat
index f0e9f24..4db23d0 100644 (file)
 
 2008-04-04  Jason Rumney  <jasonr@gnu.org>
 
-       * INSTALL: Update W32 API requirements.
+       * INSTALL: Update Windows API requirements.
 
 2008-04-03  Jason Rumney  <jasonr@gnu.org>
 
        * makefile.def (CP_DIR): Use platform independent switches for xcopy.
 
        * makefile.nt (install, fast_install, real_install, clean):
-       Don't use switches to del not supported by Win95.
+       Don't use switches to del not supported by Windows 95.
 
 1995-11-07  Kevin Gallo  <kgallo@microsoft.com>
 
 1995-05-27  Geoff Voelker  <voelker@cs.washington.edu>
 
        * ebuild.bat, emacs.bat, fast-install.bat, install.bat:
-       Add carriage returns; necessary for batch files on Win95.
+       Add carriage returns; necessary for batch files on Windows 95.
 
 1995-05-25  Geoff Voelker  <voelker@cs.washington.edu>
 
index 96ef52f..2293610 100644 (file)
 
   To compile Emacs, you will need either Microsoft Visual C++ 2.0, or
   later and nmake, or a Windows port of GCC 2.95 or later with MinGW
-  and W32 API support and a port of GNU Make.  You can use the Cygwin
+  and Windows API support and a port of GNU Make.  You can use the Cygwin
   ports of GCC, but Emacs requires the MinGW headers and libraries to
   build (latest versions of the Cygwin toolkit, at least since v1.3.3,
   include the MinGW headers and libraries as an integral part).
 * Trouble-shooting
 
   The main problems that are likely to be encountered when building
-  Emacs stem from using an old version of GCC, or old MinGW or W32 API
+  Emacs stem from using an old version of GCC, or old MinGW or Windows API
   headers.  Additionally, Cygwin ports of GNU make may require the Emacs
   source tree to be mounted with text!=binary, because the makefiles
   generated by configure.bat necessarily use DOS line endings.  Also,
   2.95 or later is needed, because that is when the Windows port gained
   sufficient support for anonymous structs and unions to cope with some
   definitions from winnt.h that are used by addsection.c.
-  Older versions of the W32 API headers that come with Cygwin and MinGW
+  Older versions of the Windows API headers that come with Cygwin and MinGW
   may be missing some definitions required by Emacs, or broken in other
   ways.  In particular, uniscribe APIs were added to MinGW CVS only on
   2006-03-26, so releases from before then cannot be used.
index e91165d..56793a0 100755 (executable)
@@ -23,7 +23,7 @@ rem   YOU'LL NEED THE FOLLOWING UTILITIES TO MAKE EMACS:
 rem\r
 rem   + MS Windows 95, NT or later\r
 rem   + either MSVC 2.x or later, or gcc-2.95 or later (with GNU make 3.75\r
-rem     or later) and the Mingw32 and W32 API headers and libraries.\r
+rem     or later) and the Mingw32 and Windows API headers and libraries.\r
 rem   + Visual Studio 2005 is not supported at this time.\r
 rem\r
 rem For reference, here is a list of which builds of GNU make are known to\r
@@ -426,7 +426,7 @@ rem   problem).  The gcc/mingw32 2.95.2 headers are okay, as are distros
 rem   of w32api-xxx.zip from Anders Norlander since 1999-11-18 at least.\r
 rem   Beginning with Emacs 23, we need usp10.h.\r
 rem\r
-echo Checking whether W32 API headers are too old...\r
+echo Checking whether Windows API headers are too old...\r
 echo #include "windows.h" >junk.c\r
 echo #include "usp10.h" >>junk.c\r
 echo test(PIMAGE_NT_HEADERS pHeader) >>junk.c\r
@@ -469,7 +469,7 @@ goto end
 echo.\r
 echo Configure failed.\r
 echo To configure Emacs for Windows, you need to have either\r
-echo gcc-2.95 or later with Mingw32 and the W32 API headers,\r
+echo gcc-2.95 or later with Mingw32 and the Windows API headers,\r
 echo or MSVC 2.x or later.\r
 del junk.c\r
 goto end\r
index 274ce7e..fc5ecef 100644 (file)
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2012 Free Software Foundation, Inc.
 #
 # Top level makefile for building GNU Emacs on Windows NT
index cc112f4..21ba05a 100644 (file)
@@ -1,3 +1,11 @@
+2012-07-29  Paul Eggert  <eggert@cs.ucla.edu>
+
+       Don't use the abbreviation "win" to refer to Windows (Bug#10421).
+       * regex.c (MAX_BUF_SIZE): Remove some incorrect and
+       long-ago-commented-out code that talks about "WIN32".
+       * w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95.
+       All uses changed.
+
 2012-07-28  Paul Eggert  <eggert@cs.ucla.edu>
 
        Use Gnulib stdalign module (Bug#9772, Bug#9960).
index cf62ec2..6eda101 100644 (file)
        * w32term.c (w32_draw_fringe_bitmap): Copy unadapted code from
        xterm.c to handle overlaid fringe bitmaps and to use cursor color
        for displaying cursor in fringe.
-       (w32_define_fringe_bitmap, w32_destroy_fringe_bitmap): New W32
+       (w32_define_fringe_bitmap, w32_destroy_fringe_bitmap): New Windows
        specific functions to define and destroy fringe bitmaps in fringe_bmp.
        (w32_redisplay_interface): Add them to redisplay_interface.
        (w32_term_init): Call w32_init_fringe instead of explicitly
        "Emacs built on Windows 9x/ME crashes at startup on Windows XP,
        or Emacs builtpart of on XP crashes at startup on Windows 9x/ME."
 
-       * w32.c: Added wrapper functions around the win32 API functions
+       * w32.c: Added wrapper functions around the Windows API functions
        OpenProcessToken, GetTokenInformation, LookupAccountSid, and
        GetSidIdentifierAuthority.  These wrapper functions serve two
        purposes:
        the version of advapi32.dll that is found in the 9x branch of
        Microsoft Windows.
 
-       * w32.c (init_user_info): Replace the calls to the win32 API
+       * w32.c (init_user_info): Replace the calls to the Windows API
        functions OpenProcessToken, GetTokenInformation, LookupAccountSid,
        and GetSidIdentifierAuthority with calls to the newly added
        wrapper functions.
index 781027e..d3b0a82 100644 (file)
 
 2010-09-24  Juanma Barranquero  <lekktu@gmail.com>
 
-       Remove W32 API function pointer unused since 2005-02-15 (revno 2005-02-15T23:19:26Z!jasonr@gnu.org).
+       Remove Windows API function pointer unused since 2005-02-15 (revno
+       2005-02-15T23:19:26Z!jasonr@gnu.org).
        * w32fns.c (clipboard_sequence_fn): Don't declare.
        (globals_of_w32fns): Don't initialize it.
 
index 3aa1a23..64f8b3a 100644 (file)
        "light", "extralight", and "thin" fonts.
        (x_to_win32_charset, win32_to_x_charset): New functions.
        (win32_to_x_font): Use new height units.  Use win32_to_x_charset.
-       (x_to_win32_font): Use x_to_win32_charset.  Support Win32 font names
+       (x_to_win32_font): Use x_to_win32_charset.  Support w32 font names
        in addition to X font names.
 
        (win32_load_font, Fx_list_fonts, Fx_display_color_cells)
 
        * xdisp.c [HAVE_NTGUI] (set_menu_framebar): Declare external.
        [HAVE_NTGUI] (frame_title_buf, frame_title_ptr): Include variables
-       for Win32 window system.
+       for w32 window system.
        [HAVE_NTGUI] (store_frame_title, x_consider_frame_title): Include
-       procedures for Win32 window system.
-       [HAVE_NTGUI] (x_consider_frame_title): Test for Win32 frame.
-       [HAVE_NTGUI] (display_text_line): Test for Win32 frame on face change.
+       procedures for w32 window system.
+       [HAVE_NTGUI] (x_consider_frame_title): Test for w32 frame.
+       [HAVE_NTGUI] (display_text_line): Test for w32 frame on face change.
        [HAVE_NTGUI] (display_menu_bar): Perform no-op for NT window system.
 
        * window.c [HAVE_NTGUI] (Fset_window_configuration): Set menu
        (make_lispy_event): Use FUNCTION_KEY_OFFSET to modify event codes
        before applying modifiers.
 
-       * frame.c [HAVE_NTGUI]: Test for a Win32 frame in procedures
+       * frame.c [HAVE_NTGUI]: Test for a w32 frame in procedures
        that test for an X frame.
 
        * frame.h (output_method): New method: output_win32.
        * emacs.c [HAVE_NTGUI]: Declare Vwindow_system.
        [HAVE_NTGUI] (main): Enable inhibit_window_system.
        Initialize environment from registry.
-       Declare syms of Win32 windowing modules.
+       Declare syms of w32 windowing modules.
 
        * dispnew.c [HAVE_NTGUI]: Include w32term.h.
        Include dispextern.h before cm.h since dispextern.h includes windows.h.
        [HAVE_NTGUI] (make_frame_glyphs, free_frame_glyphs, scroll_frame_lines)
-       (update_frame, update_line): Test for WIN32 frame.
-       [HAVE_NTGUI] (init_display): Initialize WIN32 window system.
+       (update_frame, update_line): Test for w32 frame.
+       [HAVE_NTGUI] (init_display): Initialize w32 window system.
 
        * dispextern.h [HAVE_NTGUI]: Include win32.h.
        [HAVE_NTGUI] (struct frame_glyphs): Include pixel fields.
index 0952826..ce240ab 100644 (file)
        (sys_select): Ignore children dead children with pending input.
        Delay sending SIGCHLD until all output has been read.
        (sys_kill): Sleep to allow focus change events to propagate.
-       Use TerminateProcess on Win95.
+       Use TerminateProcess on Windows 95.
        (int_from_hex, enum_locale_fn, Fw32_get_valid_locale_ids):
        New functions.
        (Vw32_valid_locale_ids): New variable.
        Loop over handles round robin to ensure fairness.
        (sys_kill): Send ctrl-break and ctrl-c keystrokes to subprocesses
        on SIGINT if not sharing consoles, otherwise generate ctrl-break event.
-       On other termination signals, send WM_QUIT message to Win95 apps
+       On other termination signals, send WM_QUIT message to Windows 95 apps
        and WM_CLOSE to NT apps.
        (syms_of_ntproc): Intern new symbols.  defsubr new functions.
        DEFVAR new variables.
 
-       * w32term.c (SIF_*): Win95 macros defined for NT.
-       (struct tagSCROLLINFO): Win95 struct defined for NT.
+       * w32term.c (SIF_*): Windows 95 macros defined for NT.
+       (struct tagSCROLLINFO): Windows 95 struct defined for NT.
        (vertical_scroll_bar_min_handle, vertical_scroll_bar_top_border)
        (vertical_scroll_bar_bottom_border, last_scroll_bar_drag_pos)
        (Vw32_gab_focus_on_raise, Vw32_capslock_is_shiftlock):
index d3ce1eb..e68966b 100644 (file)
        * w32.c (stat): GetFileInformationByHandle can legitimately fail,
        so don't rely on it succeeding.
 
-       * w32fns.c (x_to_w32_font): Specify DEFAULT_CHARSET in the w32
+       * w32fns.c (x_to_w32_font): Specify DEFAULT_CHARSET in the Windows
        LOGFONT struct if x font doesn't specify the charset.
        (x_to_w32_charset): Change >= to == when testing results of
        stricmp.
index 93388d4..c1b1310 100644 (file)
@@ -986,7 +986,7 @@ static int
 xd_find_watch_fd (DBusWatch *watch)
 {
 #if HAVE_DBUS_WATCH_GET_UNIX_FD
-  /* TODO: Reverse these on Win32, which prefers the opposite.  */
+  /* TODO: Reverse these on w32, which prefers the opposite.  */
   int fd = dbus_watch_get_unix_fd (watch);
   if (fd == -1)
     fd = dbus_watch_get_socket (watch);
index a2d1c36..ada19cc 100644 (file)
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
 # Copyright (C) 2000-2012  Free Software Foundation, Inc.
 
 # This file is part of GNU Emacs.
index 4bf1194..43ee2c4 100644 (file)
@@ -1739,20 +1739,6 @@ static int analyse_first (re_char *p, re_char *pend,
    be too small, many things would have to change.  */
 # define MAX_BUF_SIZE (1L << 15)
 
-#if 0  /* This is when we thought it could be 2^16 bytes.  */
-/* Any other compiler which, like MSC, has allocation limit below 2^16
-   bytes will have to use approach similar to what was done below for
-   MSC and drop MAX_BUF_SIZE a bit.  Otherwise you may end up
-   reallocating to 0 bytes.  Such thing is not going to work too well.
-   You have been warned!!  */
-#if defined _MSC_VER  && !defined WIN32
-/* Microsoft C 16-bit versions limit malloc to approx 65512 bytes.  */
-# define MAX_BUF_SIZE  65500L
-#else
-# define MAX_BUF_SIZE (1L << 16)
-#endif
-#endif /* 0 */
-
 /* Extend the buffer by twice its current size via realloc and
    reset the pointers that pointed into the old block to point to the
    correct places in the new one.  If extending the buffer results in it
index 151bc1a..403f082 100644 (file)
@@ -31,7 +31,7 @@ along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.  */
   cause an error to be generated.
 
   The Windows implementation of play-sound is implemented via the
-  Win32 API functions mciSendString, waveOutGetVolume, and
+  Windows API functions mciSendString, waveOutGetVolume, and
   waveOutSetVolume which are exported by Winmm.dll.
 */
 
index 55b076e..cd1d927 100644 (file)
--- a/src/w32.c
+++ b/src/w32.c
@@ -1,4 +1,4 @@
/* Utility and Unix shadow routines for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1994-1995, 2000-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -2011,7 +2011,7 @@ fdutimens (int fd, char const *file, struct timespec const timespec[2])
 
 
 /* ------------------------------------------------------------------------- */
/* IO support and wrapper functions for W32 API. */
 /* ------------------------------------------------------------------------- */
 
 /* Place a wrapper around the MSVC version of ctime.  It returns NULL
@@ -2929,7 +2929,7 @@ sys_rename (const char * oldname, const char * newname)
   /* volume_info is set indirectly by map_w32_filename.  */
   oldname_dev = volume_info.serialnum;
 
-  if (os_subtype == OS_WIN95)
+  if (os_subtype == OS_WINDOWS_95)
     {
       char * o;
       char * p;
index c3a1c5d..7658585 100644 (file)
@@ -1,4 +1,4 @@
/* Terminal hooks for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1992, 1999, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -515,7 +515,7 @@ w32con_set_terminal_modes (struct terminal *t)
 {
   CONSOLE_CURSOR_INFO cci;
 
/* make cursor big and visible (100 on Win95 makes it disappear)  */
   cci.dwSize = 99;
   cci.bVisible = TRUE;
   (void) SetConsoleCursorInfo (cur_screen, &cci);
index 1b1c500..97b7001 100644 (file)
@@ -1,4 +1,4 @@
/* Graphical user interface functions for the Microsoft W32 API.
 
 Copyright (C) 1989, 1992-2012  Free Software Foundation, Inc.
 
@@ -6575,7 +6575,7 @@ If the underlying system call fails, value is nil.  */)
   value = Qnil;
 
   /* Determining the required information on Windows turns out, sadly,
-     to be more involved than one would hope.  The original Win32 api
+     to be more involved than one would hope.  The original Windows API
      call for this will return bogus information on some systems, but we
      must dynamically probe for the replacement api, since that was
      added rather late on.  */
index 8137882..fd24a90 100644 (file)
@@ -1,4 +1,4 @@
/* Font backend for the Microsoft W32 API.
    Copyright (C) 2007-2012 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -292,7 +292,7 @@ intern_font_name (char * string)
   Lisp_Object str = DECODE_SYSTEM (build_string (string));
   int len = SCHARS (str);
   Lisp_Object obarray = check_obarray (Vobarray);
-  Lisp_Object tem = oblookup (obarray, SDATA (str), len, len);  
+  Lisp_Object tem = oblookup (obarray, SDATA (str), len, len);
   /* This code is similar to intern function from lread.c.  */
   return SYMBOLP (tem) ? tem : Fintern (str, obarray);
 }
@@ -1394,7 +1394,7 @@ font_matches_spec (DWORD type, NEWTEXTMETRICEX *font,
                    currently appear in fontset.el, so it isn't worth
                    creating a mapping table of codepages/scripts to languages
                    or opening the font to see if there are any language tags
-                   in it that the W32 API does not expose. Fontset
+                   in it that the Windows API does not expose. Fontset
                   spec should have a fallback, as some backends do
                   not recognize language at all.  */
                return 0;
index 40edafa..b08d48a 100644 (file)
@@ -1,4 +1,4 @@
/* Shared GDI and Uniscribe Font backend declarations for the W32 API.
    Copyright (C) 2007-2012 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
index 1e800e3..1ea185b 100644 (file)
@@ -1,4 +1,4 @@
/* Definitions and headers for communication on the Microsoft W32 API.
    Copyright (C) 1995, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
index cc5e5cd..e34021b 100644 (file)
@@ -1,4 +1,4 @@
/* Heap management routines for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1994, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -66,7 +66,7 @@ cache_system_info (void)
   w32_minor_version = version.info.minor;
 
   if (version.info.platform & 0x8000)
-    os_subtype = OS_WIN95;
+    os_subtype = OS_WINDOWS_95;
   else
     os_subtype = OS_NT;
 
@@ -79,7 +79,7 @@ cache_system_info (void)
   GetVersionEx (&osinfo_cache);
 
   w32_build_number = osinfo_cache.dwBuildNumber;
-  if (os_subtype == OS_WIN95)
+  if (os_subtype == OS_WINDOWS_95)
     w32_build_number &= 0xffff;
 }
 
index b2d5165..7a20ba2 100644 (file)
@@ -51,7 +51,7 @@ extern int                  w32_minor_version;
 extern int           w32_build_number;
 
 enum {
-  OS_WIN95 = 1,
+  OS_WINDOWS_95 = 1,
   OS_NT
 };
 
@@ -92,4 +92,3 @@ IMAGE_SECTION_HEADER * find_section (char * name, IMAGE_NT_HEADERS * nt_header);
 IMAGE_SECTION_HEADER * rva_to_section (DWORD rva, IMAGE_NT_HEADERS * nt_header);
 
 #endif /* NTHEAP_H_ */
-
index 8d04119..6d86972 100644 (file)
@@ -1,4 +1,4 @@
/* Input event support for Emacs on the Microsoft W32 API.
    Copyright (C) 1992-1993, 1995, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
index 5386f2a..c874e58 100644 (file)
@@ -1,4 +1,4 @@
/* Input routines for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1995, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -30,4 +30,3 @@ extern void w32_console_mouse_position (FRAME_PTR *f, int insist,
                                        unsigned long *time);
 
 #endif /* EMACS_W32INEVT_H */
-
index 871baed..09484d7 100644 (file)
@@ -1,4 +1,4 @@
/* Menu support for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1986, 1988, 1993-1994, 1996, 1998-1999, 2001-2012
                  Free Software Foundation, Inc.
 
index afc1b21..15b0ea2 100644 (file)
@@ -1,4 +1,4 @@
/* Process support for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1992, 1995, 1999-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -799,7 +799,7 @@ sys_spawnve (int mode, char *cmdname, char **argv, char **envp)
   unixtodos_filename (cmdname);
   argv[0] = cmdname;
 
/* Determine whether program is a 16-bit DOS executable, or a w32
      executable that is implicitly linked to the Cygnus dll (implying it
      was compiled with the Cygnus GNU toolchain and hence relies on
      cygwin.dll to parse the command line - we use this to decide how to
@@ -1386,7 +1386,7 @@ find_child_console (HWND hwnd, LPARAM arg)
 
       GetClassName (hwnd, window_class, sizeof (window_class));
       if (strcmp (window_class,
-                 (os_subtype == OS_WIN95)
+                 (os_subtype == OS_WINDOWS_95)
                  ? "tty"
                  : "ConsoleWindowClass") == 0)
        {
@@ -1517,7 +1517,7 @@ sys_kill (int pid, int sig)
       if (NILP (Vw32_start_process_share_console) && cp && cp->hwnd)
        {
 #if 1
-         if (os_subtype == OS_WIN95)
+         if (os_subtype == OS_WINDOWS_95)
            {
 /*
    Another possibility is to try terminating the VDM out-right by
@@ -1536,7 +1536,7 @@ sys_kill (int pid, int sig)
 
 */
 #if 0
/* On Win95, posting WM_QUIT causes the 16-bit subsystem
                 to hang when cmdproxy is used in conjunction with
                 command.com for an interactive shell.  Posting
                 WM_CLOSE pops up a dialog that, when Yes is selected,
@@ -1810,7 +1810,7 @@ If successful, the return value is t, otherwise nil.  */)
       CHECK_NUMBER (process);
 
       /* Allow pid to be an internally generated one, or one obtained
-        externally.  This is necessary because real pids on Win95 are
+        externally.  This is necessary because real pids on Windows 95 are
         negative.  */
 
       pid = XINT (process);
index 1d4a6f4..59ff440 100644 (file)
@@ -1,4 +1,4 @@
/* Selection processing for Emacs on the Microsoft W32 API.
 
 Copyright (C) 1993-1994, 2001-2012  Free Software Foundation, Inc.
 
index 6f0065d..f02d101 100644 (file)
@@ -1,4 +1,4 @@
/* Implementation of GUI terminal on the Microsoft W32 API.
 
 Copyright (C) 1989, 1993-2012 Free Software Foundation, Inc.
 
index 4fdf560..b49104d 100644 (file)
@@ -1,4 +1,4 @@
/* Definitions and headers for communication on the Microsoft W32 API.
    Copyright (C) 1995, 2001-2012 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
index 0b0fc26..745a5cf 100644 (file)
@@ -1,4 +1,4 @@
/* Functions taken directly from X sources for use with the Microsoft W32 API.
    Copyright (C) 1989, 1992-1995, 1999, 2001-2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -1,4 +1,4 @@
-/* Utility and Unix shadow routines for GNU Emacs on the Microsoft W32 API.
+/* Utility and Unix shadow routines for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1994-1995, 2000-2012  Free Software Foundation, Inc.
 
@@ -2011,7 +2011,7 @@ fdutimens (int fd, char const *file, struct timespec const timespec[2])
 
 /* ------------------------------------------------------------------------- */
-/* IO support and wrapper functions for W32 API. */
+/* IO support and wrapper functions for the Windows API. */
 /* ------------------------------------------------------------------------- */
 
@@ -1,4 +1,4 @@
index c3a1c5d..7658585 100644 (file)
-/* Terminal hooks for GNU Emacs on the Microsoft W32 API.
+/* Terminal hooks for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1992, 1999, 2001-2012  Free Software Foundation, Inc.
 
@@ -515,7 +515,7 @@ w32con_set_terminal_modes (struct terminal *t)
   CONSOLE_CURSOR_INFO cci;
 
-  /* make cursor big and visible (100 on Win95 makes it disappear)  */
+  /* make cursor big and visible (100 on Windows 95 makes it disappear)  */
   cci.dwSize = 99;
   cci.bVisible = TRUE;
@@ -1,4 +1,4 @@
index 1b1c500..97b7001 100644 (file)
-/* Graphical user interface functions for the Microsoft W32 API.
+/* Graphical user interface functions for the Microsoft Windows API.
 
 Copyright (C) 1989, 1992-2012  Free Software Foundation, Inc.
@@ -1,4 +1,4 @@
index 8137882..fd24a90 100644 (file)
-/* Font backend for the Microsoft W32 API.
+/* Font backend for the Microsoft Windows API.
    Copyright (C) 2007-2012 Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index 40edafa..b08d48a 100644 (file)
-/* Shared GDI and Uniscribe Font backend declarations for the W32 API.
+/* Shared GDI and Uniscribe Font backend declarations for the Windows API.
    Copyright (C) 2007-2012 Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index 1e800e3..1ea185b 100644 (file)
-/* Definitions and headers for communication on the Microsoft W32 API.
+/* Definitions and headers for communication on the Microsoft Windows API.
    Copyright (C) 1995, 2001-2012  Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index cc5e5cd..e34021b 100644 (file)
-/* Heap management routines for GNU Emacs on the Microsoft W32 API.
+/* Heap management routines for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1994, 2001-2012  Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index 8d04119..6d86972 100644 (file)
-/* Input event support for Emacs on the Microsoft W32 API.
+/* Input event support for Emacs on the Microsoft Windows API.
    Copyright (C) 1992-1993, 1995, 2001-2012  Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index 5386f2a..c874e58 100644 (file)
-/* Input routines for GNU Emacs on the Microsoft W32 API.
+/* Input routines for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1995, 2001-2012  Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index 871baed..09484d7 100644 (file)
-/* Menu support for GNU Emacs on the Microsoft W32 API.
+/* Menu support for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1986, 1988, 1993-1994, 1996, 1998-1999, 2001-2012
                  Free Software Foundation, Inc.
@@ -1,4 +1,4 @@
index afc1b21..15b0ea2 100644 (file)
-/* Process support for GNU Emacs on the Microsoft W32 API.
+/* Process support for GNU Emacs on the Microsoft Windows API.
    Copyright (C) 1992, 1995, 1999-2012  Free Software Foundation, Inc.
 
@@ -799,7 +799,7 @@ sys_spawnve (int mode, char *cmdname, char **argv, char **envp)
   argv[0] = cmdname;
 
-  /* Determine whether program is a 16-bit DOS executable, or a w32
+  /* Determine whether program is a 16-bit DOS executable, or a 32-bit Windows
      executable that is implicitly linked to the Cygnus dll (implying it
      was compiled with the Cygnus GNU toolchain and hence relies on
@@ -1536,7 +1536,7 @@ sys_kill (int pid, int sig)
 */
 #if 0
-             /* On Win95, posting WM_QUIT causes the 16-bit subsystem
+             /* On Windows 95, posting WM_QUIT causes the 16-bit subsystem
                 to hang when cmdproxy is used in conjunction with
                 command.com for an interactive shell.  Posting
@@ -1,4 +1,4 @@
index 1d4a6f4..59ff440 100644 (file)
-/* Selection processing for Emacs on the Microsoft W32 API.
+/* Selection processing for Emacs on the Microsoft Windows API.
 
 Copyright (C) 1993-1994, 2001-2012  Free Software Foundation, Inc.
@@ -1,4 +1,4 @@
index 6f0065d..f02d101 100644 (file)
-/* Implementation of GUI terminal on the Microsoft W32 API.
+/* Implementation of GUI terminal on the Microsoft Windows API.
 
 Copyright (C) 1989, 1993-2012 Free Software Foundation, Inc.
@@ -1,4 +1,4 @@
index 4fdf560..b49104d 100644 (file)
-/* Definitions and headers for communication on the Microsoft W32 API.
+/* Definitions and headers for communication on the Microsoft Windows API.
    Copyright (C) 1995, 2001-2012 Free Software Foundation, Inc.
 
@@ -1,4 +1,4 @@
index 0b0fc26..745a5cf 100644 (file)
-/* Functions taken directly from X sources for use with the Microsoft W32 API.
+/* Functions taken directly from X sources for use with the Microsoft Windows API.
    Copyright (C) 1989, 1992-1995, 1999, 2001-2012  Free Software Foundation, Inc.
 